@@ -257,7 +257,7 @@ def render_table(data, append_headers, append_lineno):
     length = 22
     n = math.ceil(len(data["rows"]) / length)
     html = []
-    data_rows = []
+    rows = []
     for index in range(0, n+2):
         html.append(
             "<table  "
@@ -280,41 +280,44 @@ def render_table(data, append_headers, append_lineno):
         html.append("</colgroup>")
         append_headers(data, html)
         if index > 0:
-            data_rows.append(data["rows"][0:2])
-            data_rows.append(data["rows"][index*length:(index+1)*length])
+            for row in data["rows"][0:2]:
+                rows.append(row)
+            for row in data["rows"][index*length:(index+1)*length]:
+                rows.append(row)
         else :
-            data_rows.append(data["rows"][index:length])
-        for row in data_rows:
+            for row in data["rows"][index:length]:
+                rows.append(row)
+        for i, row in enumerate(rows):
             trow = [('<tr id="{}-of-{}-for-data-{}-of-{}">').format(index, n+1,index*length,(index+1)*length)]
-            # append_lineno(trow, i)
-            trow.append(('{}').format(row))
-            # for cell in row:
-            #     if cell["column"] in hidden_columns:
-            #         continue
-            #     images = data["images"].get((cell["column"], cell["row"])) or []
-            #     formatted_images = []
-            #     for img in images:
-            #         styles = render_inline_styles(img["style"])
-            #         img_tag = (
-            #             '<img width="{width}" height="{height}"'
-            #             'style="{styles_str}"'
-            #             'src="{src}"'
-            #             "/>"
-            #         ).format(styles_str=styles, **img)
-            #         formatted_images.append(img_tag)
-            #     trow.append(
-            #         (
-            #             '<td {attrs_str} style="{styles_str}">'
-            #             "{formatted_images}"
-            #             "{formatted_value}"
-            #             "</td>"
-            #         ).format(
-            #             attrs_str=render_attrs(cell["attrs"]),
-            #             styles_str=render_inline_styles(cell["style"]),
-            #             formatted_images="\n".join(formatted_images),
-            #             **cell,
-            #         )
-            #     )
+            append_lineno(trow, i)
+            # trow.append(('{}').format(row))
+            for cell in row:
+                if cell["column"] in hidden_columns:
+                    continue
+                images = data["images"].get((cell["column"], cell["row"])) or []
+                formatted_images = []
+                for img in images:
+                    styles = render_inline_styles(img["style"])
+                    img_tag = (
+                        '<img width="{width}" height="{height}"'
+                        'style="{styles_str}"'
+                        'src="{src}"'
+                        "/>"
+                    ).format(styles_str=styles, **img)
+                    formatted_images.append(img_tag)
+                trow.append(
+                    (
+                        '<td {attrs_str} style="{styles_str}">'
+                        "{formatted_images}"
+                        "{formatted_value}"
+                        "</td>"
+                    ).format(
+                        attrs_str=render_attrs(cell["attrs"]),
+                        styles_str=render_inline_styles(cell["style"]),
+                        formatted_images="\n".join(formatted_images),
+                        **cell,
+                    )
+                )
             trow.append("</tr>")
             html.append("\n".join(trow))
         html.append("</table>")
